<?php

namespace Drupal\a12s_maps_sync\Compiler;

use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Definition;

class A12sLogsCompilerPass implements CompilerPassInterface {

  /**
   * {@inheritdoc}
   */
  public function process(ContainerBuilder $container) {
    $database = $container->get('database');

    // Check directly in the database if we have enabled monolog.
    $config = $database->select('config', 'c')
      ->fields('c', ['data'])
      ->condition('name', 'a12s_maps_sync.settings')
      ->execute()
      ->fetchCol();

    if (!empty($config)) {
      $settings = unserialize($config[0]);

      if (!empty($settings['enable_monolog']) && $settings['enable_monolog'] === 1) {
        // Update the parameters in the container.
        $parameter = $container->getParameter('monolog.channel_handlers') ?? [];
        $parameter['a12s_maps_sync'] = ['a12s_rotating_file'];
        $container->setParameter('monolog.channel_handlers', $parameter);

        $definition = new Definition(
          'Monolog\Handler\RotatingFileHandler',
          ['private://logs/a12s_maps_sync.log', 10, 'DEBUG']
        );
        $container->setDefinition('monolog.handler.a12s_rotating_file', $definition);
      }
    }
  }

}
